@@ -5,13 +5,14 @@
 # AIM: automata abstract class
 from abc import ABC, abstractmethod
 
-from sentence_spliter.automata.sequence import StrSequence
+from .sequence import StrSequence
 
 
 class Criteria(ABC):
-    def __init__(self, name: str, reverse: bool = False):
+    def __init__(self, name: str, symbols: dict, reverse: bool = False, ):
         self.name = name
         self.revers = reverse
+        self.symbols = symbols
 
     @abstractmethod
     def accept(self, state: StrSequence) -> bool:
@@ -25,8 +26,9 @@ class Criteria(ABC):
 
 
 class Operation(ABC):
-    def __init__(self, name: str):
+    def __init__(self, name: str, symbols: dict):
         self.name = name
+        self.symbols = symbols
 
     @abstractmethod
     def operate(self, state: StrSequence) -> StrSequence:
