@@ -10,7 +10,6 @@ import re
 from .abc import Criteria
 from .sequence import StrSequence, EnSequence
 from .symbols import SYMBOLS, SYMBOLS_EN
-from .white_list import white_list
 
 
 class IsEndState(Criteria):
@@ -122,7 +121,7 @@ class IsSingleQuoteCloseEn(Criteria):
                 return True
             else:
                 return False
-        elif state.quota_left > 0:
+        elif state.s_quota_left > 0:
             return False
         else:
             return True
@@ -173,7 +172,7 @@ class IsSQuota(Criteria):
         if self.value == 'left':
             self.pattern = self.symbols['s_quota_left']
         elif self.value == 'right':
-            self.pattern = self.symbols['quotation_right']
+            self.pattern = self.symbols['s_quota_right']
         else:
             self.pattern = self.symbols['s_quota_en']
         self.is_blank = re.compile('^\s+')
@@ -280,8 +279,8 @@ class IsLeftQuotaZH(SpecialCondition):
 
 
 class IsLeftQuotaEn(SpecialCondition):
-    def __init__(self, SYMBOLS: dict):
-        super(IsLeftQuotaEn, self).__init__('IsListQuota', SYMBOLS)
+    def __init__(self):
+        super(IsLeftQuotaEn, self).__init__('IsListQuota', SYMBOLS_EN)
         self.blank = re.compile('\s')
 
     def accept(self, state: StrSequence) -> bool:
@@ -298,9 +297,23 @@ class IsLeftQuotaEn(SpecialCondition):
         return False
 
 
+class IsLeftSingleQuotaEn(SpecialCondition):
+    def __init__(self):
+        super(IsLeftSingleQuotaEn, self).__init__('IsLeftSingleQuotaEn', SYMBOLS_EN)
+        self.blank = re.compile('\s')
+
+    def accept(self, state: EnSequence) -> bool:
+        if self.symbols['s_quota_en'].match(state.current_value) and state.s_quota_en % 2 != 0 or self.symbols[
+            's_quota_left'].match(state.current_value):
+            # state.v_pointer = max(0, state.v_pointer - 1)
+            return True
+
+        return False
+
+
 class IsRightQuotaEn(SpecialCondition):
-    def __init__(self, SYMBOLS: dict):
-        super(IsRightQuotaEn, self).__init__('SpecialCondition', SYMBOLS)
+    def __init__(self):
+        super(IsRightQuotaEn, self).__init__('SpecialCondition', SYMBOLS_EN)
         self.blank = re.compile('\s')
 
     def accept(self, state: StrSequence) -> bool:
@@ -316,9 +329,22 @@ class IsRightQuotaEn(SpecialCondition):
         return False
 
 
+class IsRightSingleQuotaEn(SpecialCondition):
+    def __init__(self):
+        super(IsRightSingleQuotaEn, self).__init__('IsRightSingleQuotaEn', SYMBOLS_EN)
+        self.blank = re.compile('\s')
+
+    def accept(self, state: EnSequence) -> bool:
+        if self.symbols['s_quota_en'].match(state.current_value) and state.s_quota_en % 2 == 0 or self.symbols[
+            's_quota_right'].match(state.current_value):
+            return True
+
+        return False
+
+
 class DialogueIsGreaterThanEN(SpecialCondition, ABC):
-    def __init__(self, SYMBOLS: dict, length: int):
-        super(DialogueIsGreaterThanEN, self).__init__('DialogueIsGreaterThanEN', SYMBOLS)
+    def __init__(self, length: int):
+        super(DialogueIsGreaterThanEN, self).__init__('DialogueIsGreaterThanEN', SYMBOLS_EN)
         self.length = length
         self.word_pattern = re.compile('^[a-zA-Z0-9]+')
 
@@ -345,23 +371,12 @@ class DialogueIsGreaterThanEN(SpecialCondition, ABC):
                 if n_word >= self.length:
                     break
             i -= 1
-
-        return s_quota_result or quota_result
-
-
-class IsListQuotaEN(SpecialCondition):
-    def __init__(self, index=0):
-        super(IsListQuotaEN, self).__init__('IsListQuotaEN', SYMBOLS)
-        self.index = index
-
-    def accept(self, state: StrSequence) -> bool:
-        if self.index >= 0:
-            index = min(state.v_pointer + self.index, state.length - 1)
+        if n_quota == 0 and n_s_quota != 0:
+            return s_quota_result
+        elif n_quota != 0 and n_s_quota == 0:
+            return quota_result
         else:
-            index = max(0, state.v_pointer + self.index)
-        if self.symbols["quotation_en"].match(state[index]):
-            return True
-        return False
+            return s_quota_result or quota_result
 
 
 class IsLeftQuotaGreaterThan(SpecialCondition):
@@ -425,9 +440,11 @@ class NotInWhitelistDotEn(SpecialCondition):
     note: 大小写敏感
     '''
 
-    def __init__(self):
-        super(NotInWhitelistDotEn, self).__init__('NotInWhitelistDotEn', SYMBOLS)
+    def __init__(self, white_list_path: str):
+        super(NotInWhitelistDotEn, self).__init__('NotInWhitelistDotEn', SYMBOLS_EN)
         pattern = re.compile('\s')
+        with open(white_list_path, 'r') as f:
+            white_list = f.read()
         self.white_list = [pattern.sub('', v.strip()) for v in white_list.splitlines()]
 
     def accept(self, state: EnSequence) -> bool:
