@@ -102,17 +102,17 @@ class ShortHandler(Operation):
 
 
 class LongHandlerEN(Operation):
-    def __init__(self, symbols: dict, min_sentence_length: int = 5, name=None):
+    def __init__(self, symbols: dict, white_list_path: str, min_sentence_length: int = 5, name=None):
         super(LongHandlerEN, self).__init__('LongHandlerEN' if not name else name, symbols)
         self.is_end_symbol = condition.IsEndSymbolCN(symbols)
         self.is_comma = condition.IsComma(symbols)
         self.is_book_close = condition.IsBookClose(symbols)
         self.is_barcket_close = condition.IsBracketClose(symbols)
-        self.not_in_white_list = condition.NotInWhitelistDotEn()
+        self.not_in_white_list = condition.NotInWhitelistDotEn(white_list_path)
         self.is_next_with_space = condition.IsNextWithSpace(symbols)
-        self.is_right_quota = condition.IsRightQuotaEn(symbols)
+        self.is_right_quota = condition.IsRightQuotaEn()
         self.min_sentence_length = min_sentence_length
-        self.is_dialogue_gt = condition.DialogueIsGreaterThanEN(symbols, min_sentence_length)
+        self.is_dialogue_gt = condition.DialogueIsGreaterThanEN(min_sentence_length)
         self.space = self.symbols['all_symbols']
         self.blank = re.compile('^\s+$')
         self.pre_index = 0
@@ -162,6 +162,7 @@ class LongHandlerEN(Operation):
         state.bracket_right = temp_state.bracket_right
         state.s_quota_en = temp_state.s_quota_en
         state.s_quota_left = temp_state.s_quota_left
+        return state
 
     def operate(self, state: EnSequence) -> EnSequence:
         self.init_var()
@@ -171,7 +172,7 @@ class LongHandlerEN(Operation):
         if dash_success:
             state.v_pointer = min(cut_id, state.length - 1)
             state.add_to_sentence_list()
-            self.update_state_info(state, temps_state)
+            state = self.update_state_info(state, temps_state)
             return state
         else:
             temps_state = copy.copy(state)
@@ -179,7 +180,7 @@ class LongHandlerEN(Operation):
             if dialog_success:
                 state.v_pointer = min(cut_id, state.length - 1)
                 state.add_to_sentence_list()
-                self.update_state_info(state, temps_state)
+                state = self.update_state_info(state, temps_state)
                 return state
             else:
                 temps_state = copy.copy(state)
@@ -187,7 +188,7 @@ class LongHandlerEN(Operation):
                 if comma_success:
                     state.v_pointer = min(cut_id, state.length - 1)
                     state.add_to_sentence_list()
-                    self.update_state_info(state, temps_state)
+                    state = self.update_state_info(state, temps_state)
                     return state
             return state
 
@@ -200,6 +201,8 @@ class LongHandlerEN(Operation):
         sub_len = self.min_sentence_length
         state.quota_en = abs(state.quota_en - self.quota_en)
         state.quota_left = abs(state.quota_left - self.quota_left)
+        state.s_quota_en = abs(state.s_quota_en - self.s_quota_en)
+        state.s_quota_left = abs(state.s_quota_left - self.s_quota_left)
         state.bracket_right = abs(state.bracket_right - self.bracket_right)
         state.bracket_left = abs(state.bracket_left - self.bracket_left)
         best_sub_len = 0
@@ -250,7 +253,7 @@ class LongHandlerEN(Operation):
         state.quota_en = abs(state.quota_en - self.quota_en)
         state.quota_left = abs(state.quota_left - self.quota_left)
         state.s_quota_en = abs(state.s_quota_en - self.s_quota_en)
-        state.quota_left = abs(state.s_quota_left - self.s_quota_left)
+        state.s_quota_left = abs(state.s_quota_left - self.s_quota_left)
         state.bracket_right = abs(state.bracket_right - self.bracket_right)
         state.bracket_left = abs(state.bracket_left - self.bracket_left)
         for i in range(state.sentence_start + self.min_sentence_length * 2 - 1, org_pointer):
@@ -262,17 +265,18 @@ class LongHandlerEN(Operation):
             if not self.space.match(state.current_value):
                 sub_len += 1
 
-            if self.is_next_with_space(state) and self.is_end_symbol(state) and self.not_in_white_list(state) and sub_len > self.min_sentence_length:
+            if self.is_next_with_space(state) and self.is_end_symbol(state) and self.not_in_white_list(
+                    state) and sub_len > self.min_sentence_length:
                 state.v_pointer = org_pointer
                 return i, True
 
             elif self.is_right_quota(state) and sub_len > self.min_sentence_length and self.is_dialogue_gt(state) and \
-                    (self.is_next_with_space(state) or state.v_pointer == state.length-1):
+                    (self.is_next_with_space(state) or state.v_pointer == state.length - 1):
                 state.v_pointer = org_pointer
                 return min(i + 1, state.length - 1), True
 
-            elif self.is_s_quota_left(state) and sub_len > self.min_sentence_length and self.is_dialogue_gt(state) and \
-                    (self.is_next_with_space(state) or state.v_pointer == state.length-1):
+            elif self.is_s_quota_right(state) and sub_len > self.min_sentence_length and self.is_dialogue_gt(state) and \
+                    (self.is_next_with_space(state) or state.v_pointer == state.length - 1):
                 state.v_pointer = org_pointer
                 return min(i + 1, state.length - 1), True
             else:
@@ -283,6 +287,12 @@ class LongHandlerEN(Operation):
 
     def dash_handler(self, state: EnSequence) -> Tuple[int, bool]:
         org_pointer = state.v_pointer
+        state.quota_en = abs(state.quota_en - self.quota_en)
+        state.quota_left = abs(state.quota_left - self.quota_left)
+        state.s_quota_en = abs(state.s_quota_en - self.s_quota_en)
+        state.s_quota_left = abs(state.s_quota_left - self.s_quota_left)
+        state.bracket_right = abs(state.bracket_right - self.bracket_right)
+        state.bracket_left = abs(state.bracket_left - self.bracket_left)
         for i in range(state.sentence_start + self.min_sentence_length * 2 - 1, org_pointer):
             state.v_pointer = i
             state.update_quota()
@@ -321,8 +331,8 @@ class LongHandlerEN(Operation):
         # self.pre_index = org_pointer
         self.pre_sentence_start = state.sentence_start
 
-    def is_s_quota_left(self, state):
-        if self.is_s_left(state):
+    def is_s_quota_right(self, state):
+        if self.is_s_right(state):
             return True
         if self.is_s_en(state) and state.s_quota_en % 2 != 0:
             return True
