@@ -142,18 +142,54 @@ class EnSequence(StrSequence):
         self.value = self.tokenize(str_block)
         self.length = len(self.value)
         self.__candidate_len = 0
-
+        self.s_quota_en = 0
+        self.s_quota_left = 0
+        self.is_blank = re.compile('^\s+')
 
     def tokenize(self, str_block: str):
         pattern: re.Pattern = self.symbols['all_symbols']
         return [v for v in pattern.split(str_block) if v]
 
+    def __is_squota(self, re):
+        if re.match(self.current_value):
+            if self.v_pointer == 0:
+                return True
+            elif self.v_pointer == self.length - 1:
+                return True
+            elif self.is_blank.match(self.pre_value) or self.is_blank.match(self.next_value):
+                return True
+            else:
+                return False
+        return False
+
+    def update_quota(self):
+        word = self.current_value
+        if self.symbols['quotation_en'].match(word):
+            self.quota_en += 1
+        if self.symbols['quotation_left'].match(word):
+            self.quota_left += 1
+        if self.symbols['quotation_right'].match(word):
+            self.quota_en = 0
+            self.quota_left = 0
+        # -- single quota -- #
+        if self.__is_squota(self.symbols['s_quota_left']):
+            self.s_quota_left += 1
+        if self.__is_squota(self.symbols['s_quota_en']):
+            self.s_quota_en += 1
+        if self.__is_squota(self.symbols['quotation_right']):
+            self.s_quota_left = 0
+            self.s_quota_en = 0
+
+    def reset_s_quota(self):
+        self.s_quota_en = 0
+        self.s_quota_left = 0
+
     @property
     def candidate_len(self):
         return self.__candidate_len
 
     def add_to_candidate(self):
-        self.v_pointer = min(self.v_pointer + 1, self.length-1)
+        self.v_pointer = min(self.v_pointer + 1, self.length - 1)
         if not self.symbols['all_symbols'].match(self.current_value):
             self.__candidate_len += 1
 
