@@ -4,11 +4,16 @@
 # LAST MODIFIED ON:
 # AIM:
 import attrdict
+import pathlib
+import os
 
 from .automata import condition, operation
 from .automata import symbols
+from .automata.sequence import EnSequence
 
 SYMBOLS = symbols.SYMBOLS_EN
+FOLDER_PATH = pathlib.Path(__file__).absolute().parents[0]
+WHITE_LIST_PATH = os.path.join(FOLDER_PATH, 'automata/white_list.txt')
 
 
 def init_nodes(**kwargs):
@@ -30,19 +35,23 @@ def init_nodes(**kwargs):
 
         # --- sepcial Condition --- #
         'special_ends': condition.SpecialEnds(),
-        'not_in_white_list': condition.NotInWhitelistDotEn(),
+        'not_in_white_list': condition.NotInWhitelistDotEn(WHITE_LIST_PATH),
         'is_empty': condition.IsSpace(SYMBOLS),
-        'is_left_quota': condition.IsLeftQuotaEn(SYMBOLS),
-        'is_right_quota': condition.IsRightQuotaEn(SYMBOLS),
-        'dialogue_is_greater_than': condition.DialogueIsGreaterThanEN(SYMBOLS, length=min_len)
+        'is_left_quota': condition.IsLeftQuotaEn(),
+        'is_left_single_quota': condition.IsLeftSingleQuotaEn(),
+        'is_right_quota': condition.IsRightQuotaEn(),
+        'is_right_single_quota': condition.IsRightSingleQuotaEn(),
+        'dialogue_is_greater_than': condition.DialogueIsGreaterThanEN(length=min_len)
     })
 
     nodes = attrdict.AttrDict({
         'do_cut': operation.Normal(SYMBOLS, name='do_cut'),
         'cut_pre_idx': operation.CutPreIdx(SYMBOLS, name='cut_per_idx'),
-        'long_handler': operation.LongHandlerEN(SYMBOLS, min_sentence_length=min_len, name='long_handler'),
+        'long_handler': operation.LongHandlerEN(SYMBOLS, white_list_path=WHITE_LIST_PATH, min_sentence_length=min_len,
+                                                name='long_handler'),
         'init': operation.Indolent(SYMBOLS),
         'quota_handler': operation.Indolent(SYMBOLS, name='quota_handler'),
+        'quota_single_handler': operation.Indolent(SYMBOLS, name='quota_single_handler'),
         'end': operation.EndState(SYMBOLS)
     })
     return edges, nodes
@@ -61,6 +70,11 @@ def long_cuter_en(**kwargs):
              'args': all,
              'node': nodes.quota_handler},
 
+            {'edge': [edges.is_right_single_quota,
+                      edges.dialogue_is_greater_than],
+             'args': all,
+             'node': nodes.quota_single_handler},
+
             # {'edge': edges.special_ends,
             #  'node': nodes.do_cut},
 
@@ -82,6 +96,34 @@ def long_cuter_en(**kwargs):
 
         ],
 
+        nodes.quota_single_handler: [
+            {'edge': edges.is_end_state,
+             'node': nodes.end},
+
+            {'edge': [
+                edges.is_not_short_sentence,
+                edges.is_left_single_quota,
+            ],
+                'args': all,
+                'node': nodes.cut_pre_idx},
+
+            {'edge': edges.is_empty,
+             'node': nodes.quota_single_handler},
+
+            {'edge': [
+                edges.is_not_short_sentence,
+                edges.is_end_symbol,
+                edges.is_bracket_close,
+                edges.is_book_close,
+                edges.is_quote_close,
+                edges.is_single_quote_close],
+                'args': all,
+                'node': nodes.do_cut},
+
+            {'edge': None,
+             'node': nodes.init}
+        ],
+
         nodes.quota_handler: [
             {'edge': edges.is_end_state,
              'node': nodes.end},
